WhiteBread v3.0.0 WhiteBread.Gherkin.Parser.Helpers.Steps
Summary
Functions
Takes a string representing a step and adds it to the scenario as a struct
Returns the appropriate struct for a step string
Takes a string representing a step and adds it to the scenario as a struct
Returns the appropriate struct for a step string