WhiteBread v3.0.0 WhiteBread.Outputers.HTML

This generic server accumulates information about White Bread scenarios then formats them as HTML and outputs them to a file in one go.

Summary

Functions

Interface function for the ProgressReporter protocol

Functions

report(h_t_m_l, report)

Interface function for the ProgressReporter protocol.